@@ -87,6 +87,9 @@ urlpatterns = patterns(
     url(r'^job/(?P<pk>[0-9]+)/cancel$',
         'job_cancel',
         name='lava.scheduler.job.cancel'),
+    url(r'^job/(?P<pk>[0-9]+)/resubmit$',
+        'job_resubmit',
+        name='lava.scheduler.job.resubmit'),
     url(r'^job/(?P<pk>[0-9]+)/annotate_failure$',
         'job_annotate_failure',
         name='lava.scheduler.job.annotate_failure'),
